@@ -1,12 +1,15 @@
 def create_backend(app, name=None, create_protocols=None):
     if not name:
         from .core import Backend
+
         return Backend(app, create_protocols)
 
-    if name == 'vtk':
+    if name == "vtk":
         from .vtk import Backend
+
         return Backend(app, create_protocols)
 
-    if name == 'paraview':
+    if name == "paraview":
         from .paraview import Backend
-        return Backend(app, create_protocols)
\ No newline at end of file
+
+        return Backend(app, create_protocols)
