@@ -9,6 +9,7 @@ from twisted.internet import reactor
 # Only used for debug
 import json
 
+
 class CoreServer(ServerProtocol):
     authentication_token = "wslink-secret"
     app = None
@@ -48,6 +49,7 @@ class CoreServer(ServerProtocol):
     def getRPCMethod(self, name):
         if len(self.rpcMethods) == 0:
             import inspect
+
             for protocolObject in self.getLinkProtocols():
                 test = lambda x: inspect.ismethod(x) or inspect.isfunction(x)
                 for k in inspect.getmembers(protocolObject.__class__, test):
@@ -67,23 +69,23 @@ class CoreServer(ServerProtocol):
 
     def push_state_change(self, modified_state):
         if CoreServer.DEBUG:
-            print(f'=> Push state {len(json.dumps(modified_state))}')
-        self.publish('topic.ws.vue.state', modified_state)
+            print(f"=> Push state {len(json.dumps(modified_state))}")
+        self.publish("topic.ws.vue.state", modified_state)
 
     # ---------------------------------------------------------------
 
     def push_actions(self, actions):
-        self.publish('topic.ws.vue.actions', actions)
+        self.publish("topic.ws.vue.actions", actions)
 
     # ---------------------------------------------------------------
 
     def push_layout(self, layout):
-        self.publish('topic.ws.vue.layout', layout)
+        self.publish("topic.ws.vue.layout", layout)
 
     # ---------------------------------------------------------------
 
     def push_routes(self, routes):
-        self.publish('topic.ws.vue.routes', routes)
+        self.publish("topic.ws.vue.routes", routes)
 
     # ---------------------------------------------------------------
     # RPCs
@@ -106,8 +108,12 @@ class CoreServer(ServerProtocol):
     def update_state(self, changes):
         values_to_ignore = {}
         for change in changes:
-            values_to_ignore[change['key']] = change['value'] if 'value' in change else None
+            values_to_ignore[change["key"]] = (
+                change["value"] if "value" in change else None
+            )
 
         with self.app.capture_changes(values_to_ignore):
             for change in changes:
-                self.app.set(change['key'], change['value'] if 'value' in change else None)
\ No newline at end of file
+                self.app.set(
+                    change["key"], change["value"] if "value" in change else None
+                )
